@@ -48,10 +48,16 @@
 #endif
 
 #include "sg_path.hxx"
+#include <simgear/misc/sg_dir.hxx>
 
 using std::string;
 using simgear::strutils::starts_with;
 
+// Static data members used by SGPath::addAllowedPathPattern(),
+// SGPath::validate(), etc.
+string_list SGPath::read_allowed_paths;
+string_list SGPath::write_allowed_paths;
+
 /**
  * define directory path separators
  */
@@ -278,6 +284,62 @@ void SGPath::set_cached(bool cached)
   _cached = false;
 }
 
+// ***************************************************************************
+// *                    Access permissions for Nasal code                    *
+// ***************************************************************************
+
+// Static member function
+void SGPath::clearListOfAllowedPaths(bool write)
+{
+    string_list& allowed_paths(write ? write_allowed_paths : read_allowed_paths);
+    allowed_paths.clear();
+}
+
+// Static member function
+void SGPath::addAllowedPathPattern(const string& pattern, bool write)
+{
+    string_list& allowed_paths(write ? write_allowed_paths : read_allowed_paths);
+    allowed_paths.push_back(pattern);
+}
+
+// Static member function
+const string_list& SGPath::getListOfAllowedPaths(bool write)
+{
+    return write ? write_allowed_paths : read_allowed_paths;
+}
+
+SGPath SGPath::validate(bool write) const
+{
+    // Normalize the path (prevents ../../.. or symlink trickery)
+    const string normed_path = realpath().utf8Str();
+
+    const string_list& allowed_paths{
+        write ? write_allowed_paths : read_allowed_paths};
+    string::size_type star_pos;
+
+    // Check against each allowed pattern
+    for (const auto& path: allowed_paths) {
+        star_pos = path.find('*');
+        if (star_pos == string::npos) {
+            if (!(path.compare(normed_path))) {
+                return fromUtf8(normed_path);
+            }
+        } else {
+            if ((path.size()-1 <= normed_path.size()) /* long enough to be a potential match */
+                && !(path.substr(0, star_pos)
+                     .compare(normed_path.substr(0, star_pos))) /* before-star parts match */
+                && !(path.substr(star_pos+1, path.size()-star_pos-1)
+                     .compare(normed_path.substr(star_pos+1+normed_path.size()-path.size(),
+                                                 path.size()-star_pos-1))) /* after-star parts match */) {
+                return fromUtf8(normed_path);
+            }
+        }
+    }
+
+    // No match found
+    return SGPath();
+}
+
 // append another piece to the existing path
 void SGPath::append( const string& p ) {
     if ( path.empty() ) {
@@ -422,7 +484,7 @@ string SGPath::complete_lower_extension() const
 }
 
 //------------------------------------------------------------------------------
-void SGPath::validate() const
+void SGPath::updateAttrsIfNull() const
 {
   if (_cached && _cacheEnabled) {
     return;
@@ -508,7 +570,7 @@ void SGPath::checkAccess() const
     return;
   }
 
-  validate();
+  updateAttrsIfNull();
   _rwCached = true;
 }
 
@@ -527,7 +589,7 @@ bool SGPath::exists() const
     return _exists;
   }
 #endif
-  validate();
+  updateAttrsIfNull();
   return _exists;
 }
 
@@ -547,13 +609,13 @@ bool SGPath::canWrite() const
 
 bool SGPath::isDir() const
 {
-  validate();
+  updateAttrsIfNull();
   return _exists && _isDir;
 }
 
 bool SGPath::isFile() const
 {
-  validate();
+  updateAttrsIfNull();
   return _exists && _isFile;
 }
 
@@ -745,13 +807,13 @@ bool SGPath::remove()
 
 time_t SGPath::modTime() const
 {
-    validate();
+    updateAttrsIfNull();
     return _modTime;
 }
 
 size_t SGPath::sizeInBytes() const
 {
-    validate();
+    updateAttrsIfNull();
     return _size;
 }
 
@@ -992,11 +1054,12 @@ SGPath SGPath::realpath() const
     char* buf = ::realpath(path.c_str(), NULL);
 #endif
     if (!buf) // File does not exist: return the realpath it would have if created now
-              // (needed for fgValidatePath security)
+              // (needed for SGPath::validate() security)
     {
         if (path.empty()) {
-            return SGPath(".").realpath(); // current directory
+            return simgear::Dir::current().path();
         }
+
         std::string this_dir = dir();
         if (isAbsolute() && this_dir.empty()) { // top level
             this_dir = "/";
